key_naming.py
=============

`View code on Github <https://github.com/activist-org/i18n-check/blob/main/src/i18n_check/check/key_naming.py>`_

.. automodule:: i18n_check.check.key_naming
    :members:
    :private-members:
